==> jc-1.4.0.tar.gz: java/beans/ParameterDescriptor.h <==
// public class java.beans.ParameterDescriptor

// class file dependencies
// @dep_class 171fda3bb37b43ab java_beans_FeatureDescriptor
// @dep_class 21ceef8f64b34603 java_beans_ParameterDescriptor
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_beans_FeatureDescriptor

#include "java/beans/FeatureDescriptor.h"

#ifndef _JC_java_beans_ParameterDescriptor_H_
#define _JC_java_beans_ParameterDescriptor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_beans_ParameterDescriptor$sub_refs	_jc_java_beans_ParameterDescriptor$sub_refs;
typedef struct _jc_java_beans_ParameterDescriptor$sub_nonrefs	_jc_java_beans_ParameterDescriptor$sub_nonrefs;
typedef struct _jc_java_beans_ParameterDescriptor$refs	_jc_java_beans_ParameterDescriptor$refs;
typedef struct _jc_java_beans_ParameterDescriptor$nonrefs	_jc_java_beans_ParameterDescriptor$nonrefs;
typedef struct _jc_java_beans_ParameterDescriptor$object	_jc_java_beans_ParameterDescriptor$object;

typedef const struct _jc_java_beans_ParameterDescriptor$vmethods	_jc_java_beans_ParameterDescriptor$vmethods;
typedef const struct _jc_java_beans_ParameterDescriptor$vtable	_jc_java_beans_ParameterDescriptor$vtable;
typedef const struct _jc_java_beans_ParameterDescriptor$vtype	_jc_java_beans_ParameterDescriptor$vtype;

// Constructors
extern void _jc_java_beans_ParameterDescriptor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_beans_ParameterDescriptor$object *);

// Virtual methods structure
struct _jc_java_beans_ParameterDescriptor$vmethods {
};

// Vtable
struct _jc_java_beans_ParameterDescriptor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_FeatureDescriptor$vmethods	java_beans_FeatureDescriptor;
	_jc_java_beans_ParameterDescriptor$vmethods	java_beans_ParameterDescriptor;
};

// Vtype
struct _jc_java_beans_ParameterDescriptor$vtype {
	_jc_type			type;
	_jc_java_beans_ParameterDescriptor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_ParameterDescriptor$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_beans_ParameterDescriptor$refs {
    _jc_java_beans_ParameterDescriptor$sub_refs	java_beans_ParameterDescriptor;
    _jc_java_beans_FeatureDescriptor$sub_refs	java_beans_FeatureDescriptor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_ParameterDescriptor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_ParameterDescriptor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_FeatureDescriptor$sub_nonrefs	java_beans_FeatureDescriptor;
    _jc_java_beans_ParameterDescriptor$sub_nonrefs	java_beans_ParameterDescriptor;
};

// Object instance structure
struct _jc_java_beans_ParameterDescriptor$object {
	_jc_java_beans_ParameterDescriptor$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_ParameterDescriptor$vtype	*vtype;
	_jc_java_beans_ParameterDescriptor$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_ParameterDescriptor$vtype _jc_java_beans_ParameterDescriptor$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_ParameterDescriptor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_ParameterDescriptor$class_object;

#endif	/* _JC_java_beans_ParameterDescriptor_H_ */

==> jc-1.4.6.tar.gz: java/beans/ParameterDescriptor.h <==
// public class java.beans.ParameterDescriptor

// class file dependencies
// @dep_class 8327659df0b02789 java_beans_FeatureDescriptor
// @dep_class 21ceef8f64b34603 java_beans_ParameterDescriptor
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_beans_FeatureDescriptor

#include "java/beans/FeatureDescriptor.h"

#ifndef _JC_java_beans_ParameterDescriptor_H_
#define _JC_java_beans_ParameterDescriptor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_beans_ParameterDescriptor$sub_refs	_jc_java_beans_ParameterDescriptor$sub_refs;
typedef struct _jc_java_beans_ParameterDescriptor$sub_nonrefs	_jc_java_beans_ParameterDescriptor$sub_nonrefs;
typedef struct _jc_java_beans_ParameterDescriptor$refs	_jc_java_beans_ParameterDescriptor$refs;
typedef struct _jc_java_beans_ParameterDescriptor$nonrefs	_jc_java_beans_ParameterDescriptor$nonrefs;
typedef struct _jc_java_beans_ParameterDescriptor$object	_jc_java_beans_ParameterDescriptor$object;

typedef const struct _jc_java_beans_ParameterDescriptor$vmethods	_jc_java_beans_ParameterDescriptor$vmethods;
typedef const struct _jc_java_beans_ParameterDescriptor$vtable	_jc_java_beans_ParameterDescriptor$vtable;
typedef const struct _jc_java_beans_ParameterDescriptor$vtype	_jc_java_beans_ParameterDescriptor$vtype;

// Constructors
extern void _jc_java_beans_ParameterDescriptor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_beans_ParameterDescriptor$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_beans_ParameterDescriptor$vmethods {
};

// Vtable
struct _jc_java_beans_ParameterDescriptor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_FeatureDescriptor$vmethods	java_beans_FeatureDescriptor;
	_jc_java_beans_ParameterDescriptor$vmethods	java_beans_ParameterDescriptor;
};

// Vtype
struct _jc_java_beans_ParameterDescriptor$vtype {
	_jc_type			type;
	_jc_java_beans_ParameterDescriptor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_ParameterDescriptor$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_beans_ParameterDescriptor$refs {
    _jc_java_beans_ParameterDescriptor$sub_refs	java_beans_ParameterDescriptor;
    _jc_java_beans_FeatureDescriptor$sub_refs	java_beans_FeatureDescriptor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_ParameterDescriptor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_ParameterDescriptor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_FeatureDescriptor$sub_nonrefs	java_beans_FeatureDescriptor;
    _jc_java_beans_ParameterDescriptor$sub_nonrefs	java_beans_ParameterDescriptor;
};

// Object instance structure
struct _jc_java_beans_ParameterDescriptor$object {
	_jc_java_beans_ParameterDescriptor$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_ParameterDescriptor$vtype	*vtype;
	_jc_java_beans_ParameterDescriptor$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_ParameterDescriptor$vtype _jc_java_beans_ParameterDescriptor$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_ParameterDescriptor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_ParameterDescriptor$class_object;

#endif	/* _JC_java_beans_ParameterDescriptor_H_ */
